Documentation
¶
Overview ¶
Package mainflux acts as an umbrella package containing multiple different microservices and defines all shared domain concepts.
Index ¶
- Constants
- Variables
- func Env(key, fallback string) string
- func RegisterAuthServiceServer(s *grpc.Server, srv AuthServiceServer)
- func RegisterThingsServiceServer(s *grpc.Server, srv ThingsServiceServer)
- func Version(service string) http.HandlerFunc
- type AccessByIDReq
- func (*AccessByIDReq) Descriptor() ([]byte, []int)
- func (m *AccessByIDReq) GetChanID() string
- func (m *AccessByIDReq) GetThingID() string
- func (m *AccessByIDReq) Marshal() (dAtA []byte, err error)
- func (m *AccessByIDReq) MarshalTo(dAtA []byte) (int, error)
- func (m *AccessByIDReq) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*AccessByIDReq) ProtoMessage()
- func (m *AccessByIDReq) Reset()
- func (m *AccessByIDReq) Size() (n int)
- func (m *AccessByIDReq) String() string
- func (m *AccessByIDReq) Unmarshal(dAtA []byte) error
- func (m *AccessByIDReq) XXX_DiscardUnknown()
- func (m *AccessByIDReq) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AccessByIDReq) XXX_Merge(src proto.Message)
- func (m *AccessByIDReq) XXX_Size() int
- func (m *AccessByIDReq) XXX_Unmarshal(b []byte) error
- type AccessByKeyReq
- func (*AccessByKeyReq) Descriptor() ([]byte, []int)
- func (m *AccessByKeyReq) GetChanID() string
- func (m *AccessByKeyReq) GetToken() string
- func (m *AccessByKeyReq) Marshal() (dAtA []byte, err error)
- func (m *AccessByKeyReq) MarshalTo(dAtA []byte) (int, error)
- func (m *AccessByKeyReq) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*AccessByKeyReq) ProtoMessage()
- func (m *AccessByKeyReq) Reset()
- func (m *AccessByKeyReq) Size() (n int)
- func (m *AccessByKeyReq) String() string
- func (m *AccessByKeyReq) Unmarshal(dAtA []byte) error
- func (m *AccessByKeyReq) XXX_DiscardUnknown()
- func (m *AccessByKeyReq) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AccessByKeyReq) XXX_Merge(src proto.Message)
- func (m *AccessByKeyReq) XXX_Size() int
- func (m *AccessByKeyReq) XXX_Unmarshal(b []byte) error
- type AuthServiceClient
- type AuthServiceServer
- type IssueReq
- func (*IssueReq) Descriptor() ([]byte, []int)
- func (m *IssueReq) GetIssuer() string
- func (m *IssueReq) GetType() uint32
- func (m *IssueReq) Marshal() (dAtA []byte, err error)
- func (m *IssueReq) MarshalTo(dAtA []byte) (int, error)
- func (m *IssueReq) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*IssueReq) ProtoMessage()
- func (m *IssueReq) Reset()
- func (m *IssueReq) Size() (n int)
- func (m *IssueReq) String() string
- func (m *IssueReq) Unmarshal(dAtA []byte) error
- func (m *IssueReq) XXX_DiscardUnknown()
- func (m *IssueReq) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *IssueReq) XXX_Merge(src proto.Message)
- func (m *IssueReq) XXX_Size() int
- func (m *IssueReq) XXX_Unmarshal(b []byte) error
- type Message
- func (*Message) Descriptor() ([]byte, []int)
- func (m *Message) GetChannel() string
- func (m *Message) GetContentType() string
- func (m *Message) GetPayload() []byte
- func (m *Message) GetProtocol() string
- func (m *Message) GetPublisher() string
- func (m *Message) GetSubtopic() string
- func (m *Message) Marshal() (dAtA []byte, err error)
- func (m *Message) MarshalTo(dAtA []byte) (int, error)
- func (m *Message) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*Message) ProtoMessage()
- func (m *Message) Reset()
- func (m *Message) Size() (n int)
- func (m *Message) String() string
- func (m *Message) Unmarshal(dAtA []byte) error
- func (m *Message) XXX_DiscardUnknown()
- func (m *Message) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Message) XXX_Merge(src proto.Message)
- func (m *Message) XXX_Size() int
- func (m *Message) XXX_Unmarshal(b []byte) error
- type MessagePublisher
- type Response
- type ThingID
- func (*ThingID) Descriptor() ([]byte, []int)
- func (m *ThingID) GetValue() string
- func (m *ThingID) Marshal() (dAtA []byte, err error)
- func (m *ThingID) MarshalTo(dAtA []byte) (int, error)
- func (m *ThingID) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*ThingID) ProtoMessage()
- func (m *ThingID) Reset()
- func (m *ThingID) Size() (n int)
- func (m *ThingID) String() string
- func (m *ThingID) Unmarshal(dAtA []byte) error
- func (m *ThingID) XXX_DiscardUnknown()
- func (m *ThingID) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ThingID) XXX_Merge(src proto.Message)
- func (m *ThingID) XXX_Size() int
- func (m *ThingID) XXX_Unmarshal(b []byte) error
- type ThingsServiceClient
- type ThingsServiceServer
- type Token
- func (*Token) Descriptor() ([]byte, []int)
- func (m *Token) GetValue() string
- func (m *Token) Marshal() (dAtA []byte, err error)
- func (m *Token) MarshalTo(dAtA []byte) (int, error)
- func (m *Token) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*Token) ProtoMessage()
- func (m *Token) Reset()
- func (m *Token) Size() (n int)
- func (m *Token) String() string
- func (m *Token) Unmarshal(dAtA []byte) error
- func (m *Token) XXX_DiscardUnknown()
- func (m *Token) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Token) XXX_Merge(src proto.Message)
- func (m *Token) XXX_Size() int
- func (m *Token) XXX_Unmarshal(b []byte) error
- type UnimplementedAuthServiceServer
- type UnimplementedThingsServiceServer
- func (*UnimplementedThingsServiceServer) CanAccessByID(ctx context.Context, req *AccessByIDReq) (*empty.Empty, error)
- func (*UnimplementedThingsServiceServer) CanAccessByKey(ctx context.Context, req *AccessByKeyReq) (*ThingID, error)
- func (*UnimplementedThingsServiceServer) Identify(ctx context.Context, req *Token) (*ThingID, error)
- type UserID
- func (*UserID) Descriptor() ([]byte, []int)
- func (m *UserID) GetValue() string
- func (m *UserID) Marshal() (dAtA []byte, err error)
- func (m *UserID) MarshalTo(dAtA []byte) (int, error)
- func (m *UserID) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*UserID) ProtoMessage()
- func (m *UserID) Reset()
- func (m *UserID) Size() (n int)
- func (m *UserID) String() string
- func (m *UserID) Unmarshal(dAtA []byte) error
- func (m *UserID) XXX_DiscardUnknown()
- func (m *UserID) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *UserID) XXX_Merge(src proto.Message)
- func (m *UserID) XXX_Size() int
- func (m *UserID) XXX_Unmarshal(b []byte) error
- type VersionInfo
Constants ¶
const InputChannels = "channel.>"
InputChannels represents subject all messages will be published to. Messages received on this topic are Protobuf serialized Messages.
Variables ¶
Functions ¶
func Env ¶
Env reads specified environment variable. If no value has been found, fallback is returned.
func RegisterAuthServiceServer ¶
func RegisterAuthServiceServer(s *grpc.Server, srv AuthServiceServer)
func RegisterThingsServiceServer ¶
func RegisterThingsServiceServer(s *grpc.Server, srv ThingsServiceServer)
func Version ¶
func Version(service string) http.HandlerFunc
Version exposes an HTTP handler for retrieving service version.
Types ¶
type AccessByIDReq ¶
type AccessByIDReq struct {
ThingID string `protobuf:"bytes,1,opt,name=thingID,proto3" json:"thingID,omitempty"`
ChanID string `protobuf:"bytes,2,opt,name=chanID,proto3" json:"chanID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AccessByIDReq) Descriptor ¶
func (*AccessByIDReq) Descriptor() ([]byte, []int)
func (*AccessByIDReq) GetChanID ¶
func (m *AccessByIDReq) GetChanID() string
func (*AccessByIDReq) GetThingID ¶
func (m *AccessByIDReq) GetThingID() string
func (*AccessByIDReq) Marshal ¶
func (m *AccessByIDReq) Marshal() (dAtA []byte, err error)
func (*AccessByIDReq) MarshalToSizedBuffer ¶
func (m *AccessByIDReq) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*AccessByIDReq) ProtoMessage ¶
func (*AccessByIDReq) ProtoMessage()
func (*AccessByIDReq) Reset ¶
func (m *AccessByIDReq) Reset()
func (*AccessByIDReq) Size ¶
func (m *AccessByIDReq) Size() (n int)
func (*AccessByIDReq) String ¶
func (m *AccessByIDReq) String() string
func (*AccessByIDReq) Unmarshal ¶
func (m *AccessByIDReq) Unmarshal(dAtA []byte) error
func (*AccessByIDReq) XXX_DiscardUnknown ¶
func (m *AccessByIDReq) XXX_DiscardUnknown()
func (*AccessByIDReq) XXX_Marshal ¶
func (m *AccessByIDReq) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AccessByIDReq) XXX_Merge ¶
func (m *AccessByIDReq) XXX_Merge(src proto.Message)
func (*AccessByIDReq) XXX_Size ¶
func (m *AccessByIDReq) XXX_Size() int
func (*AccessByIDReq) XXX_Unmarshal ¶
func (m *AccessByIDReq) XXX_Unmarshal(b []byte) error
type AccessByKeyReq ¶
type AccessByKeyReq struct {
Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
ChanID string `protobuf:"bytes,2,opt,name=chanID,proto3" json:"chanID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AccessByKeyReq) Descriptor ¶
func (*AccessByKeyReq) Descriptor() ([]byte, []int)
func (*AccessByKeyReq) GetChanID ¶
func (m *AccessByKeyReq) GetChanID() string
func (*AccessByKeyReq) GetToken ¶
func (m *AccessByKeyReq) GetToken() string
func (*AccessByKeyReq) Marshal ¶
func (m *AccessByKeyReq) Marshal() (dAtA []byte, err error)
func (*AccessByKeyReq) MarshalToSizedBuffer ¶
func (m *AccessByKeyReq) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*AccessByKeyReq) ProtoMessage ¶
func (*AccessByKeyReq) ProtoMessage()
func (*AccessByKeyReq) Reset ¶
func (m *AccessByKeyReq) Reset()
func (*AccessByKeyReq) Size ¶
func (m *AccessByKeyReq) Size() (n int)
func (*AccessByKeyReq) String ¶
func (m *AccessByKeyReq) String() string
func (*AccessByKeyReq) Unmarshal ¶
func (m *AccessByKeyReq) Unmarshal(dAtA []byte) error
func (*AccessByKeyReq) XXX_DiscardUnknown ¶
func (m *AccessByKeyReq) XXX_DiscardUnknown()
func (*AccessByKeyReq) XXX_Marshal ¶
func (m *AccessByKeyReq) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AccessByKeyReq) XXX_Merge ¶
func (m *AccessByKeyReq) XXX_Merge(src proto.Message)
func (*AccessByKeyReq) XXX_Size ¶
func (m *AccessByKeyReq) XXX_Size() int
func (*AccessByKeyReq) XXX_Unmarshal ¶
func (m *AccessByKeyReq) XXX_Unmarshal(b []byte) error
type AuthServiceClient ¶
type AuthServiceClient interface {
Issue(ctx context.Context, in *IssueReq, opts ...grpc.CallOption) (*Token, error)
Identify(ctx context.Context, in *Token, opts ...grpc.CallOption) (*UserID, error)
}
AuthServiceClient is the client API for AuthService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewAuthServiceClient ¶
func NewAuthServiceClient(cc *grpc.ClientConn) AuthServiceClient
type AuthServiceServer ¶
type AuthServiceServer interface {
Issue(context.Context, *IssueReq) (*Token, error)
Identify(context.Context, *Token) (*UserID, error)
}
AuthServiceServer is the server API for AuthService service.
type IssueReq ¶
type IssueReq struct {
Issuer string `protobuf:"bytes,1,opt,name=issuer,proto3" json:"issuer,omitempty"`
Type uint32 `protobuf:"varint,2,opt,name=type,proto3" json:"type,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*IssueReq) Descriptor ¶
func (*IssueReq) MarshalToSizedBuffer ¶
func (*IssueReq) ProtoMessage ¶
func (*IssueReq) ProtoMessage()
func (*IssueReq) XXX_DiscardUnknown ¶
func (m *IssueReq) XXX_DiscardUnknown()
func (*IssueReq) XXX_Marshal ¶
func (*IssueReq) XXX_Unmarshal ¶
type Message ¶
type Message struct {
Channel string `protobuf:"bytes,1,opt,name=channel,proto3" json:"channel,omitempty"`
Subtopic string `protobuf:"bytes,2,opt,name=subtopic,proto3" json:"subtopic,omitempty"`
Publisher string `protobuf:"bytes,3,opt,name=publisher,proto3" json:"publisher,omitempty"`
Protocol string `protobuf:"bytes,4,opt,name=protocol,proto3" json:"protocol,omitempty"`
ContentType string `protobuf:"bytes,5,opt,name=contentType,proto3" json:"contentType,omitempty"`
Payload []byte `protobuf:"bytes,6,opt,name=payload,proto3" json:"payload,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message represents a message emitted by the Mainflux adapters layer.
func (*Message) Descriptor ¶
func (*Message) GetChannel ¶
func (*Message) GetContentType ¶
func (*Message) GetPayload ¶
func (*Message) GetProtocol ¶
func (*Message) GetPublisher ¶
func (*Message) GetSubtopic ¶
func (*Message) MarshalToSizedBuffer ¶
func (*Message) ProtoMessage ¶
func (*Message) ProtoMessage()
func (*Message) XXX_DiscardUnknown ¶
func (m *Message) XXX_DiscardUnknown()
func (*Message) XXX_Marshal ¶
func (*Message) XXX_Unmarshal ¶
type MessagePublisher ¶
type MessagePublisher interface {
// Publishes message to the stream. A non-nil error is returned to indicate
// operation failure.
Publish(context.Context, string, Message) error
}
MessagePublisher specifies a message publishing API.
type Response ¶
type Response interface {
// Code returns HTTP response code.
Code() int
// Headers returns map of HTTP headers with their values.
Headers() map[string]string
// Empty indicates if HTTP response has content.
Empty() bool
}
Response contains HTTP response specific methods.
type ThingID ¶
type ThingID struct {
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*ThingID) Descriptor ¶
func (*ThingID) MarshalToSizedBuffer ¶
func (*ThingID) ProtoMessage ¶
func (*ThingID) ProtoMessage()
func (*ThingID) XXX_DiscardUnknown ¶
func (m *ThingID) XXX_DiscardUnknown()
func (*ThingID) XXX_Marshal ¶
func (*ThingID) XXX_Unmarshal ¶
type ThingsServiceClient ¶
type ThingsServiceClient interface {
CanAccessByKey(ctx context.Context, in *AccessByKeyReq, opts ...grpc.CallOption) (*ThingID, error)
CanAccessByID(ctx context.Context, in *AccessByIDReq, opts ...grpc.CallOption) (*empty.Empty, error)
Identify(ctx context.Context, in *Token, opts ...grpc.CallOption) (*ThingID, error)
}
ThingsServiceClient is the client API for ThingsService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewThingsServiceClient ¶
func NewThingsServiceClient(cc *grpc.ClientConn) ThingsServiceClient
type ThingsServiceServer ¶
type ThingsServiceServer interface {
CanAccessByKey(context.Context, *AccessByKeyReq) (*ThingID, error)
CanAccessByID(context.Context, *AccessByIDReq) (*empty.Empty, error)
Identify(context.Context, *Token) (*ThingID, error)
}
ThingsServiceServer is the server API for ThingsService service.
type Token ¶
type Token struct {
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
If a token is not carrying any information itself, the type field can be used to determine how to validate the token. Also, different tokens can be encoded in different ways.
func (*Token) Descriptor ¶
func (*Token) ProtoMessage ¶
func (*Token) ProtoMessage()
func (*Token) XXX_DiscardUnknown ¶
func (m *Token) XXX_DiscardUnknown()
func (*Token) XXX_Marshal ¶
func (*Token) XXX_Unmarshal ¶
type UnimplementedAuthServiceServer ¶
type UnimplementedAuthServiceServer struct {
}
UnimplementedAuthServiceServer can be embedded to have forward compatible implementations.
type UnimplementedThingsServiceServer ¶
type UnimplementedThingsServiceServer struct {
}
UnimplementedThingsServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedThingsServiceServer) CanAccessByID ¶
func (*UnimplementedThingsServiceServer) CanAccessByID(ctx context.Context, req *AccessByIDReq) (*empty.Empty, error)
func (*UnimplementedThingsServiceServer) CanAccessByKey ¶
func (*UnimplementedThingsServiceServer) CanAccessByKey(ctx context.Context, req *AccessByKeyReq) (*ThingID, error)
type UserID ¶
type UserID struct {
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*UserID) Descriptor ¶
func (*UserID) MarshalToSizedBuffer ¶
func (*UserID) ProtoMessage ¶
func (*UserID) ProtoMessage()
func (*UserID) XXX_DiscardUnknown ¶
func (m *UserID) XXX_DiscardUnknown()
func (*UserID) XXX_Marshal ¶
func (*UserID) XXX_Unmarshal ¶
type VersionInfo ¶
type VersionInfo struct {
// Service contains service name.
Service string `json:"service"`
// Version contains service current version value.
Version string `json:"version"`
}
VersionInfo contains version endpoint response.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
api
Package api contains implementation of Auth service HTTP API.
|
Package api contains implementation of Auth service HTTP API. |
|
api/grpc
Package grpc contains implementation of users service gRPC API.
|
Package grpc contains implementation of users service gRPC API. |
|
postgres
Package postgres contains Ley repository implementations using PostgreSQL as the underlying database.
|
Package postgres contains Ley repository implementations using PostgreSQL as the underlying database. |
|
tracing
Package tracing contains middlewares that will add spans to existing traces.
|
Package tracing contains middlewares that will add spans to existing traces. |
|
uuid
Package uuid provides a UUID identity provider.
|
Package uuid provides a UUID identity provider. |
|
Package bootstrap contains the domain concept definitions needed to support Mainflux bootstrap service functionality.
|
Package bootstrap contains the domain concept definitions needed to support Mainflux bootstrap service functionality. |
|
api
Package api contains implementation of bootstrap service HTTP API.
|
Package api contains implementation of bootstrap service HTTP API. |
|
postgres
Package postgres contains repository implementations using PostgreSQL as the underlying database.
|
Package postgres contains repository implementations using PostgreSQL as the underlying database. |
|
redis/consumer
Package consumer contains events consumer for events published by Things service.
|
Package consumer contains events consumer for events published by Things service. |
|
redis/producer
Package producer contains the domain events needed to support event sourcing of Bootstrap service actions.
|
Package producer contains the domain events needed to support event sourcing of Bootstrap service actions. |
|
cmd
|
|
|
auth
command
|
|
|
bootstrap
command
|
|
|
cassandra-reader
command
|
|
|
cassandra-writer
command
|
|
|
cli
command
|
|
|
coap
command
|
|
|
http
command
|
|
|
influxdb-reader
command
|
|
|
influxdb-writer
command
|
|
|
lora
command
|
|
|
mongodb-reader
command
|
|
|
mongodb-writer
command
|
|
|
opcua
command
|
|
|
postgres-reader
command
|
|
|
postgres-writer
command
|
|
|
things
command
|
|
|
users
command
|
|
|
ws
command
|
|
|
Package coap contains the domain concept definitions needed to support Mainflux coap adapter service functionality.
|
Package coap contains the domain concept definitions needed to support Mainflux coap adapter service functionality. |
|
api
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations.
|
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations. |
|
nats
Package nats contains NATS message publisher implementation.
|
Package nats contains NATS message publisher implementation. |
|
Package http contains the domain concept definitions needed to support Mainflux http adapter service functionality.
|
Package http contains the domain concept definitions needed to support Mainflux http adapter service functionality. |
|
api
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations.
|
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations. |
|
nats
Package nats contains NATS message publisher implementation.
|
Package nats contains NATS message publisher implementation. |
|
internal
|
|
|
Package logger contains logger API definition, wrapper that can be used around any other logger.
|
Package logger contains logger API definition, wrapper that can be used around any other logger. |
|
nats
Package nats contains NATS message publisher implementation.
|
Package nats contains NATS message publisher implementation. |
|
cassandra
Package cassandra contains Cassandra specific reader implementation.
|
Package cassandra contains Cassandra specific reader implementation. |
|
influxdb
Package influxdb contains the domain concept definitions needed to support Mainflux InfluxDB reader service functionality.
|
Package influxdb contains the domain concept definitions needed to support Mainflux InfluxDB reader service functionality. |
|
mongodb
Package mongodb contains the domain concept definitions needed to support Mainflux MondoDB reader service functionality.
|
Package mongodb contains the domain concept definitions needed to support Mainflux MondoDB reader service functionality. |
|
postgres
Package postgres contains repository implementations using Postgres as the underlying database.
|
Package postgres contains repository implementations using Postgres as the underlying database. |
|
sdk
|
|
|
Package things contains the domain concept definitions needed to support Mainflux things service functionality.
|
Package things contains the domain concept definitions needed to support Mainflux things service functionality. |
|
api
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations.
|
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations. |
|
api/auth/grpc
Package grpc contains implementation of things service gRPC API.
|
Package grpc contains implementation of things service gRPC API. |
|
api/auth/http
Package http contains implementation of things auth service HTTP API.
|
Package http contains implementation of things auth service HTTP API. |
|
api/things/http
Package http contains implementation of things service HTTP API.
|
Package http contains implementation of things service HTTP API. |
|
postgres
Package postgres contains repository implementations using PostgreSQL as the underlying database.
|
Package postgres contains repository implementations using PostgreSQL as the underlying database. |
|
redis
Package redis contains cache implementations using Redis as the underlying database.
|
Package redis contains cache implementations using Redis as the underlying database. |
|
tracing
Package tracing contains middlewares that will add spans to existing traces.
|
Package tracing contains middlewares that will add spans to existing traces. |
|
users
Package users contains implementation for users service in single user scenario.
|
Package users contains implementation for users service in single user scenario. |
|
uuid
Package uuid provides a UUID identity provider.
|
Package uuid provides a UUID identity provider. |
|
tools
|
|
|
mqtt-bench/cmd
command
|
|
|
provision/cmd
command
|
|
|
Package transformers contains the domain concept definitions needed to support Mainflux transformer services functionality.
|
Package transformers contains the domain concept definitions needed to support Mainflux transformer services functionality. |
|
api
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations.
|
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations. |
|
api/http
Package http contains implementation of users service HTTP API.
|
Package http contains implementation of users service HTTP API. |
|
bcrypt
Package bcrypt provides a hasher implementation utilising bcrypt.
|
Package bcrypt provides a hasher implementation utilising bcrypt. |
|
postgres
Package postgres contains repository implementations using PostgreSQL as the underlying database.
|
Package postgres contains repository implementations using PostgreSQL as the underlying database. |
|
token
Package token provides password recovery token generation with jwt Token is sent by email to user as part of recovery URL Token is signed by secret signature
|
Package token provides password recovery token generation with jwt Token is sent by email to user as part of recovery URL Token is signed by secret signature |
|
tracing
Package tracing contains middlewares that will add spans to existing traces.
|
Package tracing contains middlewares that will add spans to existing traces. |
|
Package writers contain the domain concept definitions needed to support Mainflux writer services functionality.
|
Package writers contain the domain concept definitions needed to support Mainflux writer services functionality. |
|
cassandra
Package cassandra contains the domain concept definitions needed to support Mainflux Cassandra writer service.
|
Package cassandra contains the domain concept definitions needed to support Mainflux Cassandra writer service. |
|
influxdb
Package influxdb contains the domain concept definitions needed to support Mainflux InfluxDB writer service functionality.
|
Package influxdb contains the domain concept definitions needed to support Mainflux InfluxDB writer service functionality. |
|
mongodb
Package mongodb contains the domain concept definitions needed to support Mainflux MondoDB writer service functionality.
|
Package mongodb contains the domain concept definitions needed to support Mainflux MondoDB writer service functionality. |
|
postgres
Package postgres contains repository implementations using Postgres as the underlying database.
|
Package postgres contains repository implementations using Postgres as the underlying database. |
|
Package ws contains the domain concept definitions needed to support Mainflux ws adapter service functionality.
|
Package ws contains the domain concept definitions needed to support Mainflux ws adapter service functionality. |
|
api
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations.
|
Package api contains API-related concerns: endpoint definitions, middlewares and all resource representations. |
|
nats
Package nats contains NATS message publisher implementation.
|
Package nats contains NATS message publisher implementation. |